@@ -328,6 +328,11 @@ class TableClient:
         )
 
     def move_data(self, source: TableId, target: TableId) -> Cmd[None]:
+        """
+        This method moves data from source to target.
+        After the operation source will be empty.
+        Both tables must exists.
+        """
         stm = """
             ALTER TABLE {target_schema}.{target_table}
             APPEND FROM {source_schema}.{source_table}
@@ -344,24 +349,30 @@ class TableClient:
 
     @deprecated(reason="Renamed method, use 'move_data' instead")  # type: ignore[misc]
     def append(self, source: TableId, target: TableId) -> Cmd[None]:
-        """
-        This method moves data from source to target.
-        After the operation source will be empty.
-        """
         return self.move_data(source, target)
 
     def move(self, source: TableId, target: TableId) -> Cmd[None]:
-        return self.move_data(source, target) + self.delete(source)
+        """
+        - create target if not exist
+        - move_data (append) data from source into target
+        - delete source table
+        """
+        nothing = Cmd.from_cmd(lambda: None)
+        create = self.exist(target).bind(
+            lambda b: self.create_like(source, target) if not b else nothing
+        )
+        return create + self.move_data(source, target) + self.delete(source)
 
     def migrate(self, source: TableId, target: TableId) -> Cmd[None]:
+        """
+        - delete target if exist
+        - move source into target (see move method)
+        """
         nothing = Cmd.from_cmd(lambda: None)
-        recreate = self.exist(target).bind(
-            lambda b: self.delete_cascade(target)
-            + self.create_like(source, target)
-            if b
-            else nothing
+        delete = self.exist(target).bind(
+            lambda b: self.delete_cascade(target) if b else nothing
         )
-        return recreate + self.move(source, target)
+        return delete + self.move(source, target)
 
     @deprecated(reason="Renamed method, use 'migrate' instead")  # type: ignore[misc]
     def overwrite(self, source: TableId, target: TableId) -> Cmd[None]:
